# Perplexica Integration

Users can quickly launch Perplexica via FreeGenius Hub system tray.

<img width="313" alt="Perplexica" src="https://github.com/eliranwong/freegenius/assets/25262722/bb1651f4-0321-4f9a-9e4a-c2f113021736">

FreeGenius automatically set up Perplexica for Linux users.

Windows / macOS users need to set up manually. Read: https://github.com/ItzCrazyKns/Perplexica

Default location of Perplexica is set to: ~/freegenius/Perplexica

You can customise Perplexica location by modifying item 'perplexica_directory' in config.py.